==> im-sdk_11.4.1483.orig.tar.gz: im-sdk-r11_4-1483/include/iiimp/iiimp-opcode.h <==
#if !defined(IIIMP_OPCODE_H)
#define IIIMP_OPCODE_H

#pragma ident	"$Id: iiimp-opcode.h,v 1.1.1.1 2002/08/31 04:18:10 himi Exp $"


#ifdef	__cplusplus
extern "C" {
#endif

enum IIIMP_OPCODES {
	IM_NOP = 0,

	IM_CONNECT = 1,
	IM_CONNECT_REPLY = 2,
	IM_DISCONNECT = 3,
	IM_DISCONNECT_REPLY = 4,
	IM_REGISTER_TRIGGER_KEYS = 5,
	IM_TRIGGER_NOTIFY = 6,
	IM_TRIGGER_NOTIFY_REPLY = 7,
	IM_SETIMVALUES = 8,
	IM_SETIMVALUES_REPLY = 9,
	IM_GETIMVALUES = 10,
	IM_GETIMVALUES_REPLY = 11,

	IM_FORWARD_EVENT = 12,
	IM_FORWARD_EVENT_REPLY = 13,
	IM_COMMIT_STRING = 14,

	IM_FORWARD_EVENT_WITH_OPERATIONS = 15,
	IM_FORWARD_EVENT_WITH_OPERATIONS_REPLY = 16,

	IM_CREATEIC = 20,
	IM_CREATEIC_REPLY = 21,
	IM_DESTROYIC = 22,
	IM_DESTROYIC_REPLY = 23,
	IM_SETICVALUES = 24,
	IM_SETICVALUES_REPLY = 25,
	IM_GETICVALUES = 26,
	IM_GETICVALUES_REPLY = 27,
	IM_SETICFOCUS = 28,
	IM_SETICFOCUS_REPLY = 29,
	IM_UNSETICFOCUS = 30,
	IM_UNSETICFOCUS_REPLY = 31,
	IM_RESETIC = 32,
	IM_RESETIC_REPLY = 33,

	IM_PREEDIT_START = 40,
	IM_PREEDIT_START_REPLY = 41,
	IM_PREEDIT_DRAW = 42,
	IM_PREEDIT_DRAW_REPLY = 43,

	IM_PREEDIT_DONE = 46,
	IM_PREEDIT_DONE_REPLY = 47,

	IM_STATUS_START = 50,
	IM_STATUS_START_REPLY = 51,
	IM_STATUS_DRAW = 52,
	IM_STATUS_DRAW_REPLY = 53,
	IM_STATUS_DONE = 54,
	IM_STATUS_DONE_REPLY = 55,

	IM_LOOKUP_CHOICE_START = 70,
	IM_LOOKUP_CHOICE_START_REPLY = 71,
	IM_LOOKUP_CHOICE_DRAW = 72,
	IM_LOOKUP_CHOICE_DRAW_REPLY = 73,
	IM_LOOKUP_CHOICE_DONE = 74,
	IM_LOOKUP_CHOICE_DONE_REPLY = 75,
	IM_LOOKUP_CHOICE_PROCESS = 76,
	IM_LOOKUP_CHOICE_PROCESS_REPLY = 77,

	IM_AUX_START = 90,
	IM_AUX_START_REPLY = 91,
	IM_AUX_DRAW = 92,
	IM_AUX_DRAW_REPLY = 93,
	IM_AUX_DONE = 94,
	IM_AUX_DONE_REPLY = 95,
	IM_AUX_SETVALUES = 96,
	IM_AUX_SETVALUES_REPLY = 97,

	IM_PROTOCOL_VERSION = 100
};

#ifdef	__cplusplus
}
#endif

#endif /* !IIIMP_OPCODE_H */


/* Local Variables: */
/* c-file-style: "iiim-project" */
/* End: */

==> im-sdk_11.4.1870.orig.tar.gz: im-sdk-r11_4-1870/include/iiimp/iiimp-opcode.h <==
#if !defined(IIIMP_OPCODE_H)
#define IIIMP_OPCODE_H

#pragma ident	"$Id: iiimp-opcode.h,v 1.1.1.1 2002/08/31 04:18:10 himi Exp $"


#ifdef	__cplusplus
extern "C" {
#endif

enum IIIMP_OPCODES {
	IM_NOP = 0,

	IM_CONNECT = 1,
	IM_CONNECT_REPLY = 2,
	IM_DISCONNECT = 3,
	IM_DISCONNECT_REPLY = 4,
	IM_REGISTER_TRIGGER_KEYS = 5,
	IM_TRIGGER_NOTIFY = 6,
	IM_TRIGGER_NOTIFY_REPLY = 7,
	IM_SETIMVALUES = 8,
	IM_SETIMVALUES_REPLY = 9,
	IM_GETIMVALUES = 10,
	IM_GETIMVALUES_REPLY = 11,

	IM_FORWARD_EVENT = 12,
	IM_FORWARD_EVENT_REPLY = 13,
	IM_COMMIT_STRING = 14,

	IM_FORWARD_EVENT_WITH_OPERATIONS = 15,
	IM_FORWARD_EVENT_WITH_OPERATIONS_REPLY = 16,

	IM_REGISTER_HOTKEYS = 17,
	IM_HOTKEY_NOTIFY = 18,
	IM_HOTKEY_NOTIFY_REPLY = 19,

	IM_CREATEIC = 20,
	IM_CREATEIC_REPLY = 21,
	IM_DESTROYIC = 22,
	IM_DESTROYIC_REPLY = 23,
	IM_SETICVALUES = 24,
	IM_SETICVALUES_REPLY = 25,
	IM_GETICVALUES = 26,
	IM_GETICVALUES_REPLY = 27,
	IM_SETICFOCUS = 28,
	IM_SETICFOCUS_REPLY = 29,
	IM_UNSETICFOCUS = 30,
	IM_UNSETICFOCUS_REPLY = 31,
	IM_RESETIC = 32,
	IM_RESETIC_REPLY = 33,

	IM_HOTKEY_STATE_NOTIFY = 34,
	IM_HOTKEY_STATE_NOTIFY_REPLY = 35,

	IM_PREEDIT_START = 40,
	IM_PREEDIT_START_REPLY = 41,
	IM_PREEDIT_DRAW = 42,
	IM_PREEDIT_DRAW_REPLY = 43,

	IM_PREEDIT_DONE = 46,
	IM_PREEDIT_DONE_REPLY = 47,

	IM_STATUS_START = 50,
	IM_STATUS_START_REPLY = 51,
	IM_STATUS_DRAW = 52,
	IM_STATUS_DRAW_REPLY = 53,
	IM_STATUS_DONE = 54,
	IM_STATUS_DONE_REPLY = 55,

	IM_LOOKUP_CHOICE_START = 70,
	IM_LOOKUP_CHOICE_START_REPLY = 71,
	IM_LOOKUP_CHOICE_DRAW = 72,
	IM_LOOKUP_CHOICE_DRAW_REPLY = 73,
	IM_LOOKUP_CHOICE_DONE = 74,
	IM_LOOKUP_CHOICE_DONE_REPLY = 75,
	IM_LOOKUP_CHOICE_PROCESS = 76,
	IM_LOOKUP_CHOICE_PROCESS_REPLY = 77,

	IM_AUX_START = 90,
	IM_AUX_START_REPLY = 91,
	IM_AUX_DRAW = 92,
	IM_AUX_DRAW_REPLY = 93,
	IM_AUX_DONE = 94,
	IM_AUX_DONE_REPLY = 95,
	IM_AUX_SETVALUES = 96,
	IM_AUX_SETVALUES_REPLY = 97,
	IM_AUX_GETVALUES = 98,
	IM_AUX_GETVALUES_REPLY = 99,

	IM_PROTOCOL_VERSION = 100
};

#ifdef	__cplusplus
}
#endif

#endif /* !IIIMP_OPCODE_H */


/* Local Variables: */
/* c-file-style: "iiim-project" */
/* End: */
